@@ -64,7 +64,7 @@ def send_notifications(email, sender, email_configuration):
 
     # The HTML body of the email.
     file_name = 'Email_Template.html'
-    BODY_HTML = open('media/HTML_files' + file_name).read().format(
+    BODY_HTML = open('media/HTML_files/' + file_name).read().format(
         paragraph=email_configuration.get('Email_Content'),
         signature=email_configuration.get('Signature'),
         email_us=email_configuration.get('Email_Us'),
